`.First.lib`<-
function(libname,pkgname){
cat("### Welcome to rworldmap ###\n")
#cat("For help files type :           \t ?rworldmap\n")
cat("For help files type :           \t help(rworldmap,help_type='html')\n")
cat("For a short introduction type : \t vignette('rworldmap')\n")
}
